import os
import os.path
import shutil
import xml.etree.ElementTree as et
import zipfile

from bs4 import BeautifulSoup

import belat
import belat.schemes as bs


class FileProcessor:
    LTC = "Lat-to-cyr"
    CTL = "Cyr-to-lat"

    ALLOWED_EXT = (".txt", ".epub", ".fb2")

    def __init__(
        self,
        file_in: str,
        file_out: str,
        enc_in: str,
        enc_out: str,
        transform_direction: str,
        scheme: bs.Scheme,
        file_type: str,
    ):
        """Initialize the file processor before starting to work

        :param file_in: file path in
        :type file_in: str
        :param file_out: file path out
        :type file_out: str
        :param enc_in: input file's encoding
        :type enc_in: str
        :param enc_out: output file's encoding
        :type enc_out: str
        :param transform_direction: `"Lat-to-cyr"` or `"Cyr-to-lat"`
        :type transform_direction: str
        :param scheme: translation scheme
        :type scheme: bs.Scheme
        :param file_type: one of the types specified in :obj:`belat.fileprocessor.FileProcessor.ALLOWED_EXT`
        :type file_type: str
        """
        self.file_in = file_in
        self.file_out = file_out
        self.enc_in = enc_in
        self.enc_out = enc_out
        self.transform_direction = transform_direction
        self.scheme = scheme
        self.file_type = file_type

    def work(self):
        """Start processing the files previously set in :func:`belat.fileprocessor.FileProcessor.__init__`"""
        if self.file_type == "txt":
            txt = open(self.file_in, "r", encoding=self.enc_in).read()

            if self.transform_direction == self.CTL:
                txt = self.scheme.cyr_to_lat(txt)
            elif self.transform_direction == self.LTC:
                txt = self.scheme.lat_to_cyr(txt)

            open(self.file_out, "w", encoding=self.enc_out).write(txt)
        elif self.file_type == "epub":
            with zipfile.ZipFile(self.file_in, "r") as zf:
                zf.extractall("__TEMP__")

                root_node = et.parse(
                    os.path.join("__TEMP__", "META-INF", "container.xml")
                ).getroot()

                full_path = root_node[0][0].attrib["full-path"]

                files_dir = os.path.join("__TEMP__", os.path.split(full_path)[0])

                # Translit author's and book's name etc
                f = open(
                    os.path.join(files_dir, "content.opf"), "r", encoding=self.enc_in
                )
                text = f.read()
                soup = BeautifulSoup(text, features="xml")

                if self.transform_direction == self.CTL:
                    soup.find("dc:title").string = self.scheme.cyr_to_lat(
                        soup.find("dc:title").string
                    )
                    for i in soup.find_all("dc:creator"):
                        i.string = self.scheme.cyr_to_lat(i.string)
                elif self.transform_direction == self.LTC:
                    soup.find("dc:title").string = self.scheme.lat_to_cyr(
                        soup.find("dc:title").string
                    )
                    for i in soup.find_all("dc:creator"):
                        i.string = self.scheme.lat_to_cyr(i.string)

                # region Adding belat metatags to the file
                tag = soup.new_tag("dc:subject")
                tag.string = "be_lat"
                soup.find("metadata").append(tag)

                f.close()
                xhtml = soup.prettify()
                with open(
                    os.path.join(files_dir, "content.opf"), "w", encoding=self.enc_out
                ) as file:
                    file.write("<!--@belat: " + belat.__version__ + "-->\n")
                    file.write(xhtml)
                # endregion

                xhtml_files = []
                for dir_file in os.listdir(files_dir):
                    if "." in dir_file:
                        if dir_file[dir_file.rindex(".") :].lower() == ".xhtml":
                            xhtml_files.append(os.path.join(files_dir, dir_file))

                # Working with a file
                for xhtml_file in xhtml_files:
                    f = open(xhtml_file, "r", encoding=self.enc_in)
                    text = f.read()
                    soup = BeautifulSoup(text, features="xml")

                    if self.transform_direction == self.CTL:
                        for p in soup.find_all("p"):
                            if p.string:
                                p.string.replace_with(self.scheme.cyr_to_lat(p.string))
                            for c in p.contents:
                                c.string.replace_with(self.scheme.cyr_to_lat(c.string))
                    elif self.transform_direction == self.CTL:
                        for p in soup.find_all("p"):
                            if p.string:
                                p.string.replace_with(self.scheme.lat_to_cyr(p.string))
                            for c in p.contents:
                                c.string.replace_with(self.scheme.cyr_to_lat(c.string))
                    f.close()

                    xhtml = soup.prettify()
                    with open(xhtml_file, "w", encoding=self.enc_in) as file:
                        file.write("<!--@belat: " + belat.__version__ + "-->\n")
                        file.write(xhtml)

                # Packing the files back
                with zipfile.ZipFile(self.file_out, "w", zipfile.ZIP_DEFLATED) as zf:
                    for root, dirs, files in os.walk("__TEMP__"):
                        for file in files:
                            zf.write(
                                os.path.join(root, file),
                                os.path.relpath(
                                    os.path.join(root, file), os.path.join("__TEMP__")
                                ),
                            )

                shutil.rmtree("__TEMP__")

        elif self.file_type == "fb2":
            f_in = open(self.file_in, "r", encoding=self.enc_in).read()
            soup = BeautifulSoup(f_in, features="xml")

            # region Processing meta tags
            for i in soup.find("title-info"):
                if i.name in ["author", "translator", "annotation", "publish-info"]:
                    for k in i:
                        if self.transform_direction == self.CTL:
                            k.string = self.scheme.cyr_to_lat(k.string)
                        elif self.transform_direction == self.LTC:
                            k.string = self.scheme.lat_to_cyr(k.string)
                elif i.name == "book-title":
                    if self.transform_direction == self.CTL:
                        i.string = self.scheme.cyr_to_lat(i.string)
                    elif self.transform_direction == self.LTC:
                        i.string = self.scheme.lat_to_cyr(i.string)
            # endregion

            if self.transform_direction == self.LTC:
                for b in soup.find_all("body"):
                    for p in b.find_all("p"):
                        if p.string:
                            p.string.replace_with(self.scheme.lat_to_cyr(p.string))
                        for c in p.contents:
                            c.string.replace_with(self.scheme.lat_to_cyr(c.string))
                    for p in b.find_all("v"):
                        if p.string:
                            p.string.replace_with(self.scheme.lat_to_cyr(p.string))
                        for c in p.contents:
                            c.string.replace_with(self.scheme.lat_to_cyr(c.string))
            elif self.transform_direction == self.CTL:
                for b in soup.find_all("body"):
                    for p in b.find_all("p"):
                        if p.string:
                            p.string.replace_with(self.scheme.cyr_to_lat(p.string))
                        for c in p.contents:
                            c.string.replace_with(self.scheme.cyr_to_lat(c.string))
                    for p in b.find_all("v"):
                        if p.string:
                            p.string.replace_with(self.scheme.cyr_to_lat(p.string))
                        for c in p.contents:
                            c.string.replace_with(self.scheme.cyr_to_lat(c.string))

            xhtml = soup.prettify()
            with open(self.file_out, "w", encoding=self.enc_out) as file:
                file.write("<!--@belat: " + belat.__version__ + "-->\n")
                file.write(xhtml)



import pytest

import belat.schemes.gost1687671tb1 as bgtb1
import belat.schemes.gost1687671tb2 as bgtb2


@pytest.fixture
def dubouka_cyr():
    return """Родная мова, цудоўная мова!
Ты нашых думак уток і аснова!

Матчын дарунак ад самай калыскі,
ты самацветаў яскравая нізка.

Кожны з іх барвы дзівосныя мае,
вечным агнём зіхаціць - не згарае.

Ты мне заўсёды была дапамогай,
дзе б і якой ні хадзіў я дарогай.

Чую ў табе перазвоны крыніцы,
чую ў табе і раскат навальніцы,

чую павевы зялёнага бору,
водгулле працы у родным прасторы.

Кожнай драбнічкай ты варта пашаны,
кожнае слова вякамі стварана.

І на вякі яно жыць застаецца,
вечнае так, як народнае сэрца."""


@pytest.fixture
def dubouka_lat1():
    return """Rodnaja mova, cudoŭnaja mova!
Ty našyh dumak utok i asnova!

Matčyn darunak ad samaj kalyski,
ty samacvjetaŭ jaskravaja nizka.

Kožny z ih barvy dzivosnyja maje,
vječnym agnem zihacic' - nje zgaraje.

Ty mnje zaŭsedy byla dapamogaj,
dzje b i jakoj ni hadziŭ ja darogaj.

Čuju ŭ tabje pjerazvony krynicy,
čuju ŭ tabje i raskat naval'nicy,

čuju pavjevy zjalenaga boru,
vodgullje pracy u rodnym prastory.

Kožnaj drabničkaj ty varta pašany,
kožnaje slova vjakami stvarana.

Ì na vjaki jano žyc' zastajecca,
vječnaje tak, jak narodnaje sèrca."""


@pytest.fixture
def dubouka_lat2():
    return """Rodnaja mova, cudouhnaja mova!
Ty nashykh dumak utok ih asnova!

Matchyn darunak ad samajj kalyskih,
ty samacvetauh jaskravaja nihzka.

Kozhny z ihkh barvy dzihvosnyja mae,
vechnym agnjom zihkhacihc' - ne zgarae.

Ty mne zauhsjody byla dapamogajj,
dze b ih jakojj nih khadzihuh ja darogajj.

Chuju uh tabe perazvony krynihcy,
chuju uh tabe ih raskat naval'nihcy,

chuju pavevy zjaljonaga boru,
vodgulle pracy u rodnym prastory.

Kozhnajj drabnihchkajj ty varta pashany,
kozhnae slova vjakamih stvarana.

Ih na vjakih jano zhyc' zastaecca,
vechnae tak, jak narodnae sehrca."""


@pytest.fixture
def scheme_tb1():
    return bgtb1.Scheme()


@pytest.fixture
def scheme_tb2():
    return bgtb2.Scheme()


# Тэст на транслітэрацыю з кір у лат
def test_gost16_tb1_1(dubouka_cyr, dubouka_lat1, scheme_tb1):
    assert scheme_tb1.cyr_to_lat(dubouka_cyr) == dubouka_lat1


# Тэст з лат у кір
def test_gost16_tb1_2(dubouka_cyr, dubouka_lat1, scheme_tb1):
    assert scheme_tb1.lat_to_cyr(dubouka_lat1) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_tb1_3(dubouka_cyr, scheme_tb1):
    assert scheme_tb1.lat_to_cyr(scheme_tb1.cyr_to_lat(dubouka_cyr)) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_tb1_4(dubouka_lat1, scheme_tb1):
    assert scheme_tb1.cyr_to_lat(scheme_tb1.lat_to_cyr(dubouka_lat1)) == dubouka_lat1


# ===================================================================================


# Тэст на транслітэрацыю з кір у лат
def test_gost16_tb2_1(dubouka_cyr, dubouka_lat2, scheme_tb2):
    assert scheme_tb2.cyr_to_lat(dubouka_cyr) == dubouka_lat2


# Тэст з лат у кір
def test_gost16_tb2_2(dubouka_cyr, dubouka_lat2, scheme_tb2):
    assert scheme_tb2.lat_to_cyr(dubouka_lat2) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_tb2_3(dubouka_cyr, scheme_tb2):
    assert scheme_tb2.lat_to_cyr(scheme_tb2.cyr_to_lat(dubouka_cyr)) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_tb2_4(dubouka_lat2, scheme_tb2):
    assert scheme_tb2.cyr_to_lat(scheme_tb2.lat_to_cyr(dubouka_lat2)) == dubouka_lat2



import re

import belat.schemes as bs
from belat.exceptions import NotDoneYet


# https://baltoslav.eu/lat/index.php?mova=by
class Scheme(bs.Scheme):
    name = "Афіцыйная лацінка"
    src = "https://baltoslav.eu/lat/index.php?mova=by https://www.zedlik.com/pragramy/kir2lac-online/"

    def __init__(self):
        pass

    # Наборы літар
    l_galosn_lit = "AEOIUYaeoiuy"
    l_zychn_lit = "BVGDJŽZRMNOPRSTFCHČŠĹLŹŃŚǓbvgdjžzrlĺmnoprstfchčšźńśŭ"
    l_vialik_lit = "BVGDJŽZRMNOPRSTFCHČŠĹLŹŃŚǓAEOIUY"
    l_mal_lit = "bvgdjžzrlĺmnoprstfchčšźńśŭaeoiuy"

    c_galosn_lit = "АЕОІУЫЯЮЁаеоіуыяюё"
    c_zychn_lit = "БВГДЖЗЙКЛМНОПРСТУЎФХЦЧШбвгджзйклмнпрстфхцчш"
    c_vialik_lit = "БВГДЖЗЙКЛМНОПРСТУЎФХЦЧШАЕОІУЫЯЮ"
    c_mal_lit = "бвгджзйклмнпрстфхцчшаеоіуыяю"

    gram_baza = {
        "l_galosn_lit": l_galosn_lit,
        "l_zychn_lit": l_zychn_lit,
        "l_vialik_lit": l_vialik_lit,
        "l_mal_lit": l_mal_lit,
        "c_galosn_lit": c_galosn_lit,
        "c_zychn_lit": c_zychn_lit,
        "c_vialik_lit": c_vialik_lit,
        "c_mal_lit": c_mal_lit,
    }

    # Праца з літарай г і Г
    class ctlr_g(bs.Rule):
        def work_with(self, text, regexp_rule):
            result = text

            if regexp_rule == "г":
                return re.sub("г", "h", result)

            elif regexp_rule == "Г":
                return re.sub("Г", "H", result)

    # Праца з літарамі Е, Ю, Ё, Я, е, ю, ё, я (з ётавымі)
    # Правіла (на прыкладзе Е):
    # Je je - у пачатку слова, пасля галосных, пасля апострафа, пасля ў
    # Ie ie - пасля зычных, акрамя ў і л
    # E e - пасля л
    class ctlr_je_jo_ju_ja(bs.Rule):
        def re_find(what, where, start):
            return re.search(
                what,
                where,
            )

        def __init__(self, gram_baza):
            self.gram_baza = gram_baza

        def work_with(self, text, regexp_rule):
            je_regexp = (
                "(?<=["
                + self.gram_baza["l_galosn_lit"]
                + self.gram_baza["c_galosn_lit"]
                + r"'ўЎ\s\n])"
            )
            ie_regexp = (
                "(?<=["
                + self.gram_baza["l_zychn_lit"]
                + self.gram_baza["c_zychn_lit"]
                + "])(?<![ўЎŭǓ])"
            )
            e_regexp = ie_regexp

            work_group_small = "еёюя"
            work_group_big = "ЕЁЮЯ"

            matching = {"е": "e", "ё": "o", "ю": "u", "я": "a"}

            if regexp_rule in work_group_small:
                mtch = matching[regexp_rule]

                je_res = re.sub(je_regexp + regexp_rule, "j" + mtch, text)
                je_res = re.sub("^" + regexp_rule, "j" + mtch, je_res)
                ie_res = re.sub(ie_regexp + regexp_rule, "i" + mtch, je_res)
                return re.sub(e_regexp + regexp_rule, mtch, ie_res)
            # З улікам суседніх літар, т.е БЕРАСТ павінен быць BIERAST, а не BIeRAST
            elif regexp_rule in work_group_big:
                mtch = matching[regexp_rule.lower()]

                je_res = re.sub(je_regexp + regexp_rule, "J" + mtch, text)
                je_res = re.sub("^" + regexp_rule, "J" + mtch, je_res)
                ie_res = re.sub(ie_regexp + regexp_rule, "I" + mtch, je_res)
                e_res = re.sub(e_regexp + regexp_rule, mtch.upper(), ie_res)

                cur_st = 0
                vialik_lit = (
                    "["
                    + self.gram_baza["l_vialik_lit"]
                    + self.gram_baza["c_vialik_lit"]
                    + "]"
                )
                while "J" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("J" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
                cur_st = 0
                while "I" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("I" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
                return e_res

    # Дадатковая шліфоўка вялікіх ётавых
    class ctlr_vial_jot(bs.Rule):
        def __init__(self, gram_baza):
            self.gram_baza = gram_baza

        def work_with(self, text, regexp_rule):
            cur_st = 0
            vialik_lit = (
                "["
                + self.gram_baza["l_vialik_lit"]
                + self.gram_baza["c_vialik_lit"]
                + "]"
            )
            e_res = text
            for mtch in ["e", "o", "u", "a"]:
                while "J" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("J" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
                cur_st = 0
                while "I" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("I" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
            return e_res

    # Выбар паміж CH і Ch, ch
    class ctrl_ch(bs.Rule):
        def __init__(self, gram_baza):
            self.gram_baza = gram_baza

        def work_with(self, text, regexp_rule):
            if regexp_rule == "х":
                return re.sub("х", "ch", text)
            elif regexp_rule == "Х":
                ch_text = re.sub("Х", "Ch", text)
                cur_st = 0
                vialik_lit = (
                    "["
                    + self.gram_baza["l_vialik_lit"]
                    + self.gram_baza["c_vialik_lit"]
                    + "]"
                )
                while "Ch" in ch_text[cur_st:]:
                    cur_st = ch_text.index("Ch", cur_st)
                    try:
                        if re.match(vialik_lit, ch_text[cur_st - 1]) or re.match(
                            vialik_lit, ch_text[cur_st + 2]
                        ):
                            ch_text = (
                                ch_text[: cur_st + 1] + "H" + ch_text[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += +2
                return ch_text

    # Праца з мягкім знакам
    class miahk_zn(bs.Rule):
        def __init__(self):
            pass

        maihk_para = {
            "L": "Ĺ",
            "l": "ĺ",
            "Z": "Ź",
            "z": "ź",
            "N": "Ń",
            "n": "ń",
            "S": "Ś",
            "s": "ś",
            "C": "Ć",
            "c": "ć",
        }

        def work_with(self, text, regexp_rule):
            result = text
            for i in self.maihk_para.keys():
                result = re.sub(i + "[Ьь]", self.maihk_para[i], result)
            return result

    ctl_rules = {
        "г": ctlr_g(),
        "Г": ctlr_g(),
        "Л": "L",
        "л": "l",
        "Х": ctrl_ch(gram_baza),
        "х": ctrl_ch(gram_baza),
        "Е": ctlr_je_jo_ju_ja(gram_baza),
        "е": ctlr_je_jo_ju_ja(gram_baza),
        "Ё": ctlr_je_jo_ju_ja(gram_baza),
        "ё": ctlr_je_jo_ju_ja(gram_baza),
        "Ю": ctlr_je_jo_ju_ja(gram_baza),
        "ю": ctlr_je_jo_ju_ja(gram_baza),
        "Я": ctlr_je_jo_ju_ja(gram_baza),
        "я": ctlr_je_jo_ju_ja(gram_baza),
        "З": "Z",
        "з": "z",
        "Н": "N",
        "н": "n",
        "С": "S",
        "с": "s",
        "Ц": "C",
        "ц": "c",
        "Зь|ЗЬ": "Ź",
        "зь": "ź",
        "Ль|ЛЬ": "L",
        "ль": "l",
        "Нь|НЬ": "Ń",
        "нь": "ń",
        "Сь|СЬ": "Ś",
        "сь": "ś",
        "Ць|ЦЬ": "Ć",
        "ць": "ć",
        "А": "A",
        "а": "a",
        "Б": "B",
        "б": "b",
        "В": "V",
        "в": "v",
        "Д": "D",
        "д": "d",
        "Ж": "Ž",
        "ж": "ž",
        "І": "I",
        "і": "i",
        "Й": "J",
        "й": "j",
        "К": "K",
        "к": "k",
        "М": "M",
        "м": "m",
        "О": "O",
        "о": "o",
        "П": "P",
        "п": "p",
        "Р": "R",
        "р": "r",
        "Т": "T",
        "т": "t",
        "У": "U",
        "у": "u",
        "Ў": "Ŭ",
        "ў": "ŭ",
        "Ф": "F",
        "ф": "f",
        "Ч": "Č",
        "ч": "č",
        "Ш": "Š",
        "ш": "š",
        "Ы": "Y",
        "ы": "y",
        "Э": "E",
        "э": "e",
        "Ґ": "G",
        "ґ": "g",
        "Ь": miahk_zn(),
        "ь": miahk_zn(),
        "vial_jot": ctlr_vial_jot(gram_baza),
        "'": "",
    }

    ltc_rules = {}

    def cyr_to_lat(self, text_in):
        result = text_in
        for character in self.ctl_rules.keys():
            if isinstance(self.ctl_rules[character], str):
                result = re.sub(character, self.ctl_rules[character], result)

            elif isinstance(self.ctl_rules[character], bs.Rule):
                result = self.ctl_rules[character].work_with(
                    text=result, regexp_rule=character
                )
        return result

    def lat_to_cyr(self, text_in):
        raise NotDoneYet()



import re

import belat.schemes as bs
from belat.exceptions import NotDoneYet


# https://baltoslav.eu/lat/index.php?mova=by
class Scheme(bs.Scheme):
    name = "Класічная лацінка"
    src = "https://baltoslav.eu/lat/index.php?mova=by https://www.zedlik.com/pragramy/kir2lac-online/"

    def __init__(self):
        pass

    # Наборы літар
    l_galosn_lit = "AEOIUYaeoiuy"
    l_zychn_lit = "BVGDJŽZRMNOPRSTFCHČŠŁLŹŃŚǓbvgdjžzrlłmnoprstfchčšźńśŭ"
    l_vialik_lit = "BVGDJŽZRMNOPRSTFCHČŠŁLŹŃŚǓAEOIUY"
    l_mal_lit = "bvgdjžzrlłmnoprstfchčšźńśŭaeoiuy"

    c_galosn_lit = "АЕОІУЫЯЮЁаеоіуыяюё"
    c_zychn_lit = "БВГДЖЗЙКЛМНОПРСТУЎФХЦЧШбвгджзйклмнпрстфхцчш"
    c_vialik_lit = "БВГДЖЗЙКЛМНОПРСТУЎФХЦЧШАЕОІУЫЯЮ"
    c_mal_lit = "бвгджзйклмнпрстфхцчшаеоіуыяю"

    gram_baza = {
        "l_galosn_lit": l_galosn_lit,
        "l_zychn_lit": l_zychn_lit,
        "l_vialik_lit": l_vialik_lit,
        "l_mal_lit": l_mal_lit,
        "c_galosn_lit": c_galosn_lit,
        "c_zychn_lit": c_zychn_lit,
        "c_vialik_lit": c_vialik_lit,
        "c_mal_lit": c_mal_lit,
    }

    # Праца з літарай г і Г
    # У некаторых каранях пішацца g(выбухны гук) замест h(фрыкатыўны)
    class ctlr_g(bs.Rule):
        # @ у каранях - г або Г
        karani = [
            "@узік",
            "@анак",
            "@онт",
            "@узіч",
            "@анач",
            "@онц",
            "@анк",
            "ня@е@л",
            "маз@і",
        ]

        def work_with(self, text, regexp_rule):
            result = text

            for i in self.karani:
                cur_state = 0
                while (
                    re.search(i.replace("@", "г"), result[cur_state:], re.IGNORECASE)
                    != None
                ):
                    cur_state = re.search(
                        i.replace("@", "г"), result[cur_state:], re.IGNORECASE
                    ).start()
                    # Параўноўваем
                    # @узік
                    # ГуЗіК
                    # GуЗіК
                    try:
                        count = 0
                        while not re.match(r"\s", result[cur_state + count]):
                            if i[count] == "@":
                                if result[cur_state + count] == "Г":
                                    result = (
                                        result[: cur_state + count]
                                        + "G"
                                        + result[(cur_state + count + 1) :]
                                    )
                                elif result[cur_state + count] == "г":
                                    result = (
                                        result[: cur_state + count]
                                        + "g"
                                        + result[(cur_state + count + 1) :]
                                    )
                            count += 1
                        cur_state += count
                    except IndexError:
                        continue

            if regexp_rule == "г":
                return re.sub("г", "h", result)

            elif regexp_rule == "Г":
                return re.sub("Г", "H", result)

    # Праца з літарамі Е, Ю, Ё, Я, е, ю, ё, я (з ётавымі)
    # Правіла (на прыкладзе Е):
    # Je je - у пачатку слова, пасля галосных, пасля апострафа, пасля ў
    # Ie ie - пасля зычных, акрамя ў і л
    # E e - пасля л
    class ctlr_je_jo_ju_ja(bs.Rule):
        def __init__(self, gram_baza):
            self.gram_baza = gram_baza

        def work_with(self, text, regexp_rule):
            je_regexp = (
                "(?<=["
                + self.gram_baza["l_galosn_lit"]
                + self.gram_baza["c_galosn_lit"]
                + r"'ўЎ\s\n])"
            )
            ie_regexp = (
                "(?<=["
                + self.gram_baza["l_zychn_lit"]
                + self.gram_baza["c_zychn_lit"]
                + "])(?<![ўЎлЛŭǓlL])"
            )
            e_regexp = "(?<=[лЛlL])"

            work_group_small = "еёюя"
            work_group_big = "ЕЁЮЯ"

            matching = {"е": "e", "ё": "o", "ю": "u", "я": "a"}

            if regexp_rule in work_group_small:
                mtch = matching[regexp_rule]

                je_res = re.sub(je_regexp + regexp_rule, "j" + mtch, text)
                je_res = re.sub("^" + regexp_rule, "j" + mtch, je_res)
                ie_res = re.sub(ie_regexp + regexp_rule, "i" + mtch, je_res)
                return re.sub(e_regexp + regexp_rule, mtch, ie_res)
            # З улікам суседніх літар, т.е БЕРАСТ павінен быць BIERAST, а не BIeRAST
            elif regexp_rule in work_group_big:
                mtch = matching[regexp_rule.lower()]

                je_res = re.sub(je_regexp + regexp_rule, "J" + mtch, text)
                je_res = re.sub("^" + regexp_rule, "J" + mtch, je_res)
                ie_res = re.sub(ie_regexp + regexp_rule, "I" + mtch, je_res)
                e_res = re.sub(e_regexp + regexp_rule, mtch.upper(), ie_res)

                cur_st = 0
                vialik_lit = (
                    "["
                    + self.gram_baza["l_vialik_lit"]
                    + self.gram_baza["c_vialik_lit"]
                    + "]"
                )
                while "J" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("J" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
                cur_st = 0
                while "I" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("I" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
                return e_res

    # Дадатковая шліфоўка вялікіх ётавых
    class ctlr_vial_jot(bs.Rule):
        def __init__(self, gram_baza):
            self.gram_baza = gram_baza

        def work_with(self, text, regexp_rule):
            cur_st = 0
            vialik_lit = (
                "["
                + self.gram_baza["l_vialik_lit"]
                + self.gram_baza["c_vialik_lit"]
                + "]"
            )
            e_res = text
            for mtch in ["e", "o", "u", "a"]:
                while "J" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("J" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
                cur_st = 0
                while "I" + mtch in e_res[cur_st:]:
                    cur_st = e_res.index("I" + mtch, cur_st)
                    try:
                        if re.match(vialik_lit, e_res[cur_st - 1]) or re.match(
                            vialik_lit, e_res[cur_st + 2]
                        ):
                            e_res = (
                                e_res[: cur_st + 1] + mtch.upper() + e_res[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += 2
            return e_res

    # Выбар паміж Ł і L
    class ctlr_l(bs.Rule):
        def work_with(self, text, regexp_rule):
            excepts = "еёіюяЕЁІЮЯ"
            if regexp_rule == "л":
                li = re.sub("л(?=[" + excepts + "])", "l", text)
                return re.sub("л(?![" + excepts + "])", "ł", li)
            elif regexp_rule == "Л":
                li = re.sub("Л(?=[" + excepts + "])", "L", text)
                return re.sub("Л(?![" + excepts + "])", "Ł", li)

    # Выбар паміж CH і Ch, ch
    class ctrl_ch(bs.Rule):
        def __init__(self, gram_baza):
            self.gram_baza = gram_baza

        def work_with(self, text, regexp_rule):
            if regexp_rule == "х":
                return re.sub("х", "ch", text)
            elif regexp_rule == "Х":
                ch_text = re.sub("Х", "Ch", text)
                cur_st = 0
                vialik_lit = (
                    "["
                    + self.gram_baza["l_vialik_lit"]
                    + self.gram_baza["c_vialik_lit"]
                    + "]"
                )
                while "Ch" in ch_text[cur_st:]:
                    cur_st = ch_text.index("Ch", cur_st)
                    try:
                        if re.match(vialik_lit, ch_text[cur_st - 1]) or re.match(
                            vialik_lit, ch_text[cur_st + 2]
                        ):
                            ch_text = (
                                ch_text[: cur_st + 1] + "H" + ch_text[cur_st + 2 :]
                            )
                    except IndexError:
                        continue
                    cur_st += +2
                return ch_text

    # Праца з З С Н
    # Асіміляцыя па мягкасці
    class ctlr_assimil_pa_miahk(bs.Rule):
        def __init__(self, gram_baza):
            self.gram_baza = gram_baza
            self.use_lat_lit = gram_baza["l_zychn_lit"]

        zmiahch = "LŹŃŚĆJlźńśćj"
        post_zmiahch = "Iií"  # Пасля i \u0301 - камбін. акцэнт

        assim_para = {"Z": "Z", "z": "ź", "S": "S", "s": "ś", "C": "C", "c": "ć"}

        assim_para_n_l = {"N": "Ń", "n": "ń", "Ł": "L", "ł": "l"}

        def work_with(self, text, regexp_rule):
            result = text
            for i in self.assim_para.keys():
                aspi = self.assim_para[i]
                result = re.sub(
                    i + "(?=[" + self.zmiahch + "])(?!(Ch|CH|ch|cH|K|k|G|g|H|h))",
                    aspi,
                    result,
                )
                result = re.sub(
                    i
                    + "(?=["
                    + self.use_lat_lit
                    + "]["
                    + self.post_zmiahch
                    + "])(?!(Ch|CH|ch|cH|K|k|G|g|H|h))",
                    aspi,
                    result,
                )
            # Шліфоўка
            for i in self.assim_para.keys():
                aspi = self.assim_para[i]
                result = re.sub(
                    i
                    + "(?=["
                    + self.zmiahch
                    + "])(?!(Ch|CH|ch|cH|K|k|G|g|H|h|"
                    + aspi
                    + "|"
                    + aspi.lower()
                    + "))",
                    aspi,
                    result,
                )

            # пераўтварэнне падвоенных л і н
            # nasiennie -> nasieńnie
            for i in self.assim_para_n_l.keys():
                if i == "n" or i == "N":
                    aspi = self.assim_para_n_l[i]
                    result = re.sub(
                        i
                        + "(?=["
                        + i
                        + i.upper()
                        + "]["
                        + self.post_zmiahch
                        + "])(?!(Ch|CH|ch|cH|K|k|G|g|H|h))",
                        aspi,
                        result,
                    )
                elif i == "ł" or i == "Ł":
                    aspi = self.assim_para_n_l[i]
                    result = re.sub(
                        i
                        + "(?=["
                        + aspi
                        + aspi.upper()
                        + "])(?!(Ch|CH|ch|cH|K|k|G|g|H|h))",
                        aspi,
                        result,
                    )
            return result

    # Праца з мягкім знакам
    class miahk_zn(bs.Rule):
        def __init__(self):
            pass

        maihk_para = {
            "Ł": "L",
            "ł": "l",
            "Z": "Ź",
            "z": "ź",
            "N": "Ń",
            "n": "ń",
            "S": "Ś",
            "s": "ś",
            "C": "Ć",
            "c": "ć",
        }

        def work_with(self, text, regexp_rule):
            result = text
            for i in self.maihk_para.keys():
                result = re.sub(i + "[Ьь]", self.maihk_para[i], result)
            return result

    ctl_rules = {
        "г": ctlr_g(),
        "Г": ctlr_g(),
        "Л": ctlr_l(),
        "л": ctlr_l(),
        "Х": ctrl_ch(gram_baza),
        "х": ctrl_ch(gram_baza),
        "Е": ctlr_je_jo_ju_ja(gram_baza),
        "е": ctlr_je_jo_ju_ja(gram_baza),
        "Ё": ctlr_je_jo_ju_ja(gram_baza),
        "ё": ctlr_je_jo_ju_ja(gram_baza),
        "Ю": ctlr_je_jo_ju_ja(gram_baza),
        "ю": ctlr_je_jo_ju_ja(gram_baza),
        "Я": ctlr_je_jo_ju_ja(gram_baza),
        "я": ctlr_je_jo_ju_ja(gram_baza),
        "З": "Z",
        "з": "z",
        "Н": "N",
        "н": "n",
        "С": "S",
        "с": "s",
        "Ц": "C",
        "ц": "c",
        "Зь|ЗЬ": "Ź",
        "зь": "ź",
        "Ль|ЛЬ": "L",
        "ль": "l",
        "Нь|НЬ": "Ń",
        "нь": "ń",
        "Сь|СЬ": "Ś",
        "сь": "ś",
        "Ць|ЦЬ": "Ć",
        "ць": "ć",
        "А": "A",
        "а": "a",
        "Б": "B",
        "б": "b",
        "В": "V",
        "в": "v",
        "Д": "D",
        "д": "d",
        "Ж": "Ž",
        "ж": "ž",
        "І": "I",
        "і": "i",
        "Й": "J",
        "й": "j",
        "К": "K",
        "к": "k",
        "М": "M",
        "м": "m",
        "О": "O",
        "о": "o",
        "П": "P",
        "п": "p",
        "Р": "R",
        "р": "r",
        "Т": "T",
        "т": "t",
        "У": "U",
        "у": "u",
        "Ў": "Ŭ",
        "ў": "ŭ",
        "Ф": "F",
        "ф": "f",
        "Ч": "Č",
        "ч": "č",
        "Ш": "Š",
        "ш": "š",
        "Ы": "Y",
        "ы": "y",
        "Э": "E",
        "э": "e",
        "Ґ": "G",
        "ґ": "g",
        "Ь": miahk_zn(),
        "ь": miahk_zn(),
        "assimil": ctlr_assimil_pa_miahk(gram_baza),
        "vial_jot": ctlr_vial_jot(gram_baza),
        "'": "",
    }

    ltc_rules = {}

    def cyr_to_lat(self, text_in):
        result = text_in
        for character in self.ctl_rules.keys():
            # print(result,"\n")
            # print(" ↓↓↓ ")
            # print(character)
            if isinstance(self.ctl_rules[character], str):
                result = re.sub(character, self.ctl_rules[character], result)

            elif isinstance(self.ctl_rules[character], bs.Rule):
                result = self.ctl_rules[character].work_with(
                    text=result, regexp_rule=character
                )
        return result

    def lat_to_cyr(self, text_in):
        raise NotDoneYet()



import pytest

import belat.schemes.classic as bc


@pytest.fixture
def scheme_classic():
    return bc.Scheme()


def test_classic_1(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """Родная мова, цудоўная мова!
Ты нашых думак уток і аснова!

Матчын дарунак ад самай калыскі,
ты самацветаў яскравая нізка.

Кожны з іх барвы дзівосныя мае,
вечным агнём зіхаціць - не згарае.

Ты мне заўсёды была дапамогай,
дзе б і якой ні хадзіў я дарогай.

Чую ў табе перазвоны крыніцы,
чую ў табе і раскат навальніцы,

чую павевы зялёнага бору,
водгулле працы у родным прасторы.

Кожнай драбнічкай ты варта пашаны,
кожнае слова вякамі стварана.

І на вякі яно жыць застаецца,
вечнае так, як народнае сэрца."""
        )
        == """Rodnaja mova, cudoŭnaja mova!
Ty našych dumak utok i asnova!

Matčyn darunak ad samaj kałyski,
ty samaćvietaŭ jaskravaja nizka.

Kožny z ich barvy dzivosnyja maje,
viečnym ahniom zichacić - nie zharaje.

Ty mnie zaŭsiody była dapamohaj,
dzie b i jakoj ni chadziŭ ja darohaj.

Čuju ŭ tabie pierazvony krynicy,
čuju ŭ tabie i raskat navalnicy,

čuju pavievy zialonaha boru,
vodhulle pracy u rodnym prastory.

Kožnaj drabničkaj ty varta pašany,
kožnaje słova viakami stvarana.

I na viaki jano žyć zastajecca,
viečnaje tak, jak narodnaje serca."""
    )


def test_classic_2(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """Ад родных ніў, ад роднай хаты
У панскі двор дзеля красы
Яны, бяздольныя, узяты
Ткаць залатыя паясы.
І цягам доўгія часіны,
Дзявочыя забыўшы сны,
Свае шырокія тканіны
На лад персідскі ткуць яны.
А за сцяной смяецца поле,
Зіяе неба з-за акна, –
І думкі мкнуцца мімаволі
Туды, дзе расцвіла вясна;
Дзе блішча збожжа ў яснай далі,
Сінеюць міла васількі,
Халодным срэбрам ззяюць хвалі
Між гор ліючайся ракі;
Цямнее край зубчаты бора...
І тчэ, забыўшыся, рука,
Заміж персідскага узора,
Цвяток радзімы васілька."""
        )
        == """Ad rodnych niŭ, ad rodnaj chaty
U panski dvor dziela krasy
Jany, biazdolnyja, uziaty
Tkać załatyja pajasy.
I ciaham doŭhija časiny,
Dziavočyja zabyŭšy sny,
Svaje šyrokija tkaniny
Na ład piersidski tkuć jany.
A za ścianoj śmiajecca pole,
Zijaje nieba z-za akna, –
I dumki mknucca mimavoli
Tudy, dzie raśćviła viasna;
Dzie blišča zbožža ŭ jasnaj dali,
Siniejuć miła vasilki,
Chałodnym srebram źziajuć chvali
Miž hor lijučajsia raki;
Ciamnieje kraj zubčaty bora...
I tče, zabyŭšysia, ruka,
Zamiž piersidskaha uzora,
Cviatok radzimy vasilka."""
    )


def test_classic_3(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """Магутнае слова, ты, роднае слова!
       Са мной ты на яве і ў сне;
Душу мне затрэсла пагудкаю новай,
       Ты песень наўчыла мяне.

Бяссмертнае слова, ты, роднае слова!
       Ты крыўды, няпраўды змагло;
Хоць гналі цябе, накладалі аковы,
       Дый дарма: жывеш як жыло!

Свабоднае слова, ты, роднае слова!
       Зайграй ты смялей, весялей!
Хоць гадзіны сыкаюць, кружацца совы,
       Жывеш ты на хвалу людзей.

Загнанае слова, ты, роднае слова!
       Грымі ж над радзімай зямлёй:
Што родная мова, хоць бедная мова,
       Мілей найбагатшай чужой!"""
        )
        == """Mahutnaje słova, ty, rodnaje słova!
       Sa mnoj ty na javie i ŭ śnie;
Dušu mnie zatresła pahudkaju novaj,
       Ty piesień naŭčyła mianie.

Biasśmiertnaje słova, ty, rodnaje słova!
       Ty kryŭdy, niapraŭdy zmahło;
Choć hnali ciabie, nakładali akovy,
       Dyj darma: žyvieš jak žyło!

Svabodnaje słova, ty, rodnaje słova!
       Zajhraj ty śmialej, viesialej!
Choć hadziny sykajuć, kružacca sovy,
       Žyvieš ty na chvału ludziej.

Zahnanaje słova, ty, rodnaje słova!
       Hrymi ž nad radzimaj ziamloj:
Što rodnaja mova, choć biednaja mova,
       Milej najbahatšaj čužoj!"""
    )


def test_classic_4(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """Несупыннай хваляй плыні
За парою йшла пара,
І прабіла час хлапчыне
Гнаць у поле са двара.
Ён праслухаў навучанку,
Як быць добрым пастухом,
Справіў пугу-павіванку,
Вузлы вывязаў гурком
І пагнаў авечкі ў поле
На папары і на ролі.
Ён цяпер глядзеў больш стала:
Ён – асоба, пастушок,
Нават права меў на сала
І на цёплы кажушок."""
        )
        == """Niesupynnaj chvalaj płyni
Za paroju jšła para,
I prabiła čas chłapčynie
Hnać u pole sa dvara.
Jon prasłuchaŭ navučanku,
Jak być dobrym pastuchom,
Spraviŭ puhu-pavivanku,
Vuzły vyviazaŭ hurkom
I pahnaŭ aviečki ŭ pole
Na papary i na roli.
Jon ciapier hladzieŭ bolš stała:
Jon – asoba, pastušok,
Navat prava mieŭ na sała
I na ciopły kažušok."""
    )


def test_classic_5(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """Я бачыў, як змяняе дзень
Вакол мяне гукі на колер,
Як небасхіл пакінуў цень,
Глытаючы слова «ніколі».
Я бачыў праз туман вачэй
Усё часцей ціхае «Хопіць!».
Вядзі мяне. Глядзі ў мяне.
Не ведаю, дзе мы і хто ты.

Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой, неба, небяспечна.

Я бачыў, як вяртае час
Зімовых нас, толькі на поўдзень,
Дзе прамяні не пра мяне
Зрываюць дах, нібыта злодзей.
Я бачыў, як яе далонь
здымае боль сярод пустэчы
Ратуй мяне! Ратуй мяне!
Я ведаю, што будзе лепшым.

Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой, неба, небяспечна.
неба, небяспечна
неба, небяспечна
неба, небяспечна.
Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой.
Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой, неба, небяспечна.
неба, небяспечна
неба, небяспечна
неба, небяспечна."""
        )
        == """Ja bačyŭ, jak źmianiaje dzień
Vakoł mianie huki na koler,
Jak niebaschił pakinuŭ cień,
Hłytajučy słova «nikoli».
Ja bačyŭ praz tuman vačej
Usio čaściej cichaje «Chopić!».
Viadzi mianie. Hladzi ŭ mianie.
Nie viedaju, dzie my i chto ty.

Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma źbiehčy
Ad chutkich snoŭ tvaich, ale
Mnie być z taboj, nieba, niebiaśpiečna.

Ja bačyŭ, jak viartaje čas
Zimovych nas, tolki na poŭdzień,
Dzie pramiani nie pra mianie
Zryvajuć dach, nibyta złodziej.
Ja bačyŭ, jak jaje dałoń
zdymaje bol siarod pustečy
Ratuj mianie! Ratuj mianie!
Ja viedaju, što budzie lepšym.

Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma źbiehčy
Ad chutkich snoŭ tvaich, ale
Mnie być z taboj, nieba, niebiaśpiečna.
nieba, niebiaśpiečna
nieba, niebiaśpiečna
nieba, niebiaśpiečna.
Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma źbiehčy
Ad chutkich snoŭ tvaich, ale
Mnie być z taboj.
Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma źbiehčy
Ad chutkich snoŭ tvaich, ale
Mnie być z taboj, nieba, niebiaśpiečna.
nieba, niebiaśpiečna
nieba, niebiaśpiečna
nieba, niebiaśpiečna."""
    )


def test_classic_6(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """ДОБРА Ў ПОЛІ: ВОЛІ МНОГА
І ПРАСТОРУ-ШЫРЫНІ,
ВАБЯЦЬ ДАЛІ ТАМ МАЛОГА,
ЯК ПРЫНАДНЫЯ АГНІ.
ШТО ЁСЦЬ ТАМ, ЗА ТЫМ, УНЬ, ГАЕМ,
ДЗЕ ЗЛЯГЛІ НЯБЁС ВЯНЦЫ?
НОВЫ КРАЙ І КРАЙ ЗА КРАЕМ
І КРАІ ВА ЎСЕ КАНЦЫ!
І СНУЕЦЦА ДУМКА ТАЯ,
КАБ ПАШЫРЫЦЬ СВОЙ ПРАСТОР;
ДУМКА ЎСЮДЫ ЗАЛЯТАЕ:
ЗА СЯЛО, ЗА ХВАЛІ ГОР
І НА ХМАРКІ КІНЕ ВОКА,
ШТО, ЯК ГУСАНЬКІ, ПЛЫЛІ,
ЗАПЫТАЕ, ЯК ДАЛЁКА
ТОЕ СОНЦА АД ЗЯМЛІ.
ЯК ГЛЫБОК ТОЙ ПРАСТОР НЕМЫ,
І ЦІ МЕРЫЎ ЯГО ХТО?
І АДКАЖА ПА-СВАЕМУ:
ВЁРСТ НАПЭЎНА БУДЗЕ СТО!"""
        )
        == """DOBRA Ŭ POLI: VOLI MNOHA
I PRASTORU-ŠYRYNI,
VABIAĆ DALI TAM MAŁOHA,
JAK PRYNADNYJA AHNI.
ŠTO JOSĆ TAM, ZA TYM, UŃ, HAJEM,
DZIE ZLAHLI NIABIOS VIANCY?
NOVY KRAJ I KRAJ ZA KRAJEM
I KRAI VA ŬSIE KANCY!
I SNUJECCA DUMKA TAJA,
KAB PAŠYRYĆ SVOJ PRASTOR;
DUMKA ŬSIUDY ZALATAJE:
ZA SIAŁO, ZA CHVALI HOR
I NA CHMARKI KINIE VOKA,
ŠTO, JAK HUSAŃKI, PŁYLI,
ZAPYTAJE, JAK DALOKA
TOJE SONCA AD ZIAMLI.
JAK HŁYBOK TOJ PRASTOR NIEMY,
I CI MIERYŬ JAHO CHTO?
I ADKAŽA PA-SVAJEMU:
VIORST NAPEŬNA BUDZIE STO!"""
    )


def test_classic_7(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat(
            """І ЯШЧЭ БЫЛО ЧЫМ МІЛА
ТОЕ ПОЛЕ ХЛАПЧУКУ,
ГЭТА ТЫМ, ШТО ДЗЕД КУРЫЛА
ТАМ ЯГО ТРЫМАЎ РУКУ.
ГЭТЫ ДЗЕД – ПАСТУХ ГУРТОВЫ,
СЛАЎНЫ ДЗЕД, ДЗЯДОК – ДУША,
ГАВАРКІ, МАСТАК НА СЛОВЫ,
І ЛЮБІЎ ЁН МАЛЫША!
НЕ СМЯЯЎСЯ ДЗЕД З СЫМОНКІ,
НЕ ЎСЧУВАЎ ЯГО НІ-НІ,
ЧАСТАВАЎ З СВАЕ СКАРБОНКІ,
БАВІЎ ЦЭЛЫЯ З ІМ ДНІ.
ЗАБЯРУЦЦА Ў ЦЕНЬ ПАД ГРУШУ
І ГАВОРКУ РАСПАЧНУЦЬ.
ТУТ СЫМОНКА СВАЮ ДУШУ
МОГ ПРАД ДЗЕДАМ РАЗГАРНУЦЬ,
ЗАПЫТАЦЬ ПРА СЁЕ-ТОЕ
ДЗЕДКУ ДОБРАГА СВАЙГО,
БО СЫМОН НЕ МЕЎ СПАКОЮ –
ЎСЁ ЦІКАВІЛА ЯГО."""
        )
        == """I JAŠČE BYŁO ČYM MIŁA
TOJE POLE CHŁAPČUKU,
HETA TYM, ŠTO DZIED KURYŁA
TAM JAHO TRYMAŬ RUKU.
HETY DZIED – PASTUCH HURTOVY,
SŁAŬNY DZIED, DZIADOK – DUŠA,
HAVARKI, MASTAK NA SŁOVY,
I LUBIŬ JON MAŁYŠA!
NIE SMIAJAŬSIA DZIED Z SYMONKI,
NIE ŬSČUVAŬ JAHO NI-NI,
ČASTAVAŬ Z SVAJE SKARBONKI,
BAVIŬ CEŁYJA Z IM DNI.
ZABIARUCCA Ŭ CIEŃ PAD HRUŠU
I HAVORKU RASPAČNUĆ.
TUT SYMONKA SVAJU DUŠU
MOH PRAD DZIEDAM RAZHARNUĆ,
ZAPYTAĆ PRA SIOJE-TOJE
DZIEDKU DOBRAHA SVAJHO,
BO SYMON NIE MIEŬ SPAKOJU –
ŬSIO CIKAVIŁA JAHO."""
    )


def test_classic_71(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat("гузік ганак гонт мазгі нягеглы")
        == "guzik ganak gont mazgi niagiegły"
    )


def test_classic_8(scheme_classic):
    assert (
        scheme_classic.cyr_to_lat("ГУЗІК ГАНАК ГОНТ МАЗГІ НЯГЕГЛЫ")
        == "GUZIK GANAK GONT MAZGI NIAGIEGŁY"
    )


def test_classic_9(scheme_classic):
    assert scheme_classic.cyr_to_lat("НЕ ДЗЕ НЕДЗЕ") == "NIE DZIE NIEDZIE"



import pytest

import belat.schemes.gost7792000sysa as bgsysa
import belat.schemes.gost7792000sysb as bgsysb


@pytest.fixture
def dubouka_cyr():
    return """Родная мова, цудоўная мова!
Ты нашых думак уток і аснова!

Матчын дарунак ад самай калыскі,
ты самацветаў яскравая нізка.

Кожны з іх барвы дзівосныя мае,
вечным агнём зіхаціць - не згарае.

Ты мне заўсёды была дапамогай,
дзе б і якой ні хадзіў я дарогай.

Чую ў табе перазвоны крыніцы,
чую ў табе і раскат навальніцы,

чую павевы зялёнага бору,
водгулле працы у родным прасторы.

Кожнай драбнічкай ты варта пашаны,
кожнае слова вякамі стварана.

І на вякі яно жыць застаецца,
вечнае так, як народнае сэрца."""


@pytest.fixture
def dubouka_lat1():
    return """Rodnaâ mova, cudoŭnaâ mova!
Ty našyh dumak utok ì asnova!

Matčyn darunak ad samaj kalyskì,
ty samacvetaŭ âskravaâ nìzka.

Kožny z ìh barvy dzìvosnyâ mae,
večnym agnëm zìhacìc´ - ne zgarae.

Ty mne zaŭsëdy byla dapamogaj,
dze b ì âkoj nì hadzìŭ â darogaj.

Čuû ŭ tabe perazvony krynìcy,
čuû ŭ tabe ì raskat naval´nìcy,

čuû pavevy zâlënaga boru,
vodgulle pracy u rodnym prastory.

Kožnaj drabnìčkaj ty varta pašany,
kožnae slova vâkamì stvarana.

Ì na vâkì âno žyc´ zastaecca,
večnae tak, âk narodnae sèrca."""


@pytest.fixture
def dubouka_lat2():
    return """Rodnaya mova, cudou`naya mova!
Ty` nashy`x dumak utok i asnova!

Matchy`n darunak ad samaj kaly`ski,
ty` samacvetau` yaskravaya nizka.

Kozhny` z ix barvy` dzivosny`ya mae,
vechny`m agnyom zixacic` - ne zgarae.

Ty` mne zau`syody` by`la dapamogaj,
dze b i yakoj ni xadziu` ya darogaj.

Chuyu u` tabe perazvony` kry`nicy`,
chuyu u` tabe i raskat naval`nicy`,

chuyu pavevy` zyalyonaga boru,
vodgulle pracy` u rodny`m prastory`.

Kozhnaj drabnichkaj ty` varta pashany`,
kozhnae slova vyakami stvarana.

I na vyaki yano zhy`c` zastaecca,
vechnae tak, yak narodnae se`rca."""


@pytest.fixture
def scheme_sysa():
    return bgsysa.Scheme()


@pytest.fixture
def scheme_sysb():
    return bgsysb.Scheme()


# Тэст на транслітэрацыю з кір у лат
def test_gost16_sysa_1(dubouka_cyr, dubouka_lat1, scheme_sysa):
    assert scheme_sysa.cyr_to_lat(dubouka_cyr) == dubouka_lat1


# Тэст з лат у кір
def test_gost16_sysa_2(dubouka_cyr, dubouka_lat1, scheme_sysa):
    assert scheme_sysa.lat_to_cyr(dubouka_lat1) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_sysa_3(dubouka_cyr, scheme_sysa):
    assert scheme_sysa.lat_to_cyr(scheme_sysa.cyr_to_lat(dubouka_cyr)) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_sysa_4(dubouka_lat1, scheme_sysa):
    assert scheme_sysa.cyr_to_lat(scheme_sysa.lat_to_cyr(dubouka_lat1)) == dubouka_lat1


# ===================================================================================


# Тэст на транслітэрацыю з кір у лат
def test_gost16_sysb_1(dubouka_cyr, dubouka_lat2, scheme_sysb):
    assert scheme_sysb.cyr_to_lat(dubouka_cyr) == dubouka_lat2


# Тэст з лат у кір
def test_gost16_sysb_2(dubouka_cyr, dubouka_lat2, scheme_sysb):
    assert scheme_sysb.lat_to_cyr(dubouka_lat2) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_sysb_3(dubouka_cyr, scheme_sysb):
    assert scheme_sysb.lat_to_cyr(scheme_sysb.cyr_to_lat(dubouka_cyr)) == dubouka_cyr


# Тэст з кір у лат і наадварот
def test_gost16_sysb_4(dubouka_lat2, scheme_sysb):
    assert scheme_sysb.cyr_to_lat(scheme_sysb.lat_to_cyr(dubouka_lat2)) == dubouka_lat2



from belat.settings import SCHEMES


def main():
    print("Press Ctrl-C, Ctrl-Z or Ctrl-D to stop")

    while True:
        scheme = SCHEMES[input("Module name: ").lower().strip()]

        tr_direction = (
            input("Direction (cyr-to-lat (ctl) or lat-to-cyr (ltc)): ").lower().strip()
        )

        if tr_direction in ("ctl", "cyr-to-lat"):
            print("Result:", scheme.cyr_to_lat(input("Text: ")))
        elif tr_direction in ("ltc", "lat-to-cyr"):
            print("Result:", scheme.lat_to_cyr(input("Text: ")))


if __name__ == "__main__":
    main()



import importlib
import logging
import sys
from typing import Dict, Optional


class Scheme:
    name = "Scheme"
    src = "localhost"

    def __init__(self):
        pass

    def cyr_to_lat(self, text_in):
        pass

    def lat_to_cyr(self, text_in):
        pass


class Rule:
    def __init__(self):
        pass

    def work_with(self, text, pos, regexp):
        pass


SCHEME_MODULES = (
    "official",
    "gost1687671tb1",
    "gost1687671tb2",
    "gost7792000sysa",
    "gost7792000sysb",
    "classic",
)

logger = logging.getLogger(__name__)

schemes_dict = {}
for scheme_module in SCHEME_MODULES:
    try:
        lib = importlib.import_module("belat.schemes." + scheme_module)
        scheme = lib.Scheme()
        schemes_dict[scheme_module] = scheme

        logger.info(f"Loaded '{scheme_module}' ('{scheme.name}')")
    except Exception:
        logger.exception(f"Cannot load scheme '{scheme_module}'")
        sys.exit(-1)

SCHEMES: Dict[str, Scheme] = schemes_dict


def get_scheme_by_name(scheme_name: str) -> Optional[Scheme]:
    """Get scheme by it's `.name` property

    :param scheme_name: `.name` value of the searched scheme
    :type scheme_name: str
    :return: :class:`belat.schemes.Scheme` if found, `None` otherwise
    :rtype: Optional[Scheme]
    """
    global SCHEMES

    for v in SCHEMES.values():
        if v.name == scheme_name:
            return v

    return None



import pytest

import belat.schemes.official as bc


@pytest.fixture
def scheme_official():
    return bc.Scheme()


def test_official_1(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """Родная мова, цудоўная мова!
Ты нашых думак уток і аснова!

Матчын дарунак ад самай калыскі,
ты самацветаў яскравая нізка.

Кожны з іх барвы дзівосныя мае,
вечным агнём зіхаціць - не згарае.

Ты мне заўсёды была дапамогай,
дзе б і якой ні хадзіў я дарогай.

Чую ў табе перазвоны крыніцы,
чую ў табе і раскат навальніцы,

чую павевы зялёнага бору,
водгулле працы у родным прасторы.

Кожнай драбнічкай ты варта пашаны,
кожнае слова вякамі стварана.

І на вякі яно жыць застаецца,
вечнае так, як народнае сэрца."""
        )
        == """Rodnaja mova, cudoŭnaja mova!
Ty našych dumak utok i asnova!

Matčyn darunak ad samaj kalyski,
ty samacvietaŭ jaskravaja nizka.

Kožny z ich barvy dzivosnyja maje,
viečnym ahniom zichacić - nie zharaje.

Ty mnie zaŭsiody byla dapamohaj,
dzie b i jakoj ni chadziŭ ja darohaj.

Čuju ŭ tabie pierazvony krynicy,
čuju ŭ tabie i raskat navaĺnicy,

čuju pavievy zialionaha boru,
vodhullie pracy u rodnym prastory.

Kožnaj drabničkaj ty varta pašany,
kožnaje slova viakami stvarana.

I na viaki jano žyć zastajecca,
viečnaje tak, jak narodnaje serca."""
    )


def test_official_2(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """Ад родных ніў, ад роднай хаты
У панскі двор дзеля красы
Яны, бяздольныя, узяты
Ткаць залатыя паясы.
І цягам доўгія часіны,
Дзявочыя забыўшы сны,
Свае шырокія тканіны
На лад персідскі ткуць яны.
А за сцяной смяецца поле,
Зіяе неба з-за акна, –
І думкі мкнуцца мімаволі
Туды, дзе расцвіла вясна;
Дзе блішча збожжа ў яснай далі,
Сінеюць міла васількі,
Халодным срэбрам ззяюць хвалі
Між гор ліючайся ракі;
Цямнее край зубчаты бора...
І тчэ, забыўшыся, рука,
Заміж персідскага узора,
Цвяток радзімы васілька."""
        )
        == """Ad rodnych niŭ, ad rodnaj chaty
U panski dvor dzielia krasy
Jany, biazdoĺnyja, uziaty
Tkać zalatyja pajasy.
I ciaham doŭhija časiny,
Dziavočyja zabyŭšy sny,
Svaje šyrokija tkaniny
Na lad piersidski tkuć jany.
A za scianoj smiajecca polie,
Zijaje nieba z-za akna, –
I dumki mknucca mimavoli
Tudy, dzie rascvila viasna;
Dzie blišča zbožža ŭ jasnaj dali,
Siniejuć mila vasiĺki,
Chalodnym srebram zziajuć chvali
Miž hor lijučajsia raki;
Ciamnieje kraj zubčaty bora...
I tče, zabyŭšysia, ruka,
Zamiž piersidskaha uzora,
Cviatok radzimy vasiĺka."""
    )


def test_official_3(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """Магутнае слова, ты, роднае слова!
       Са мной ты на яве і ў сне;
Душу мне затрэсла пагудкаю новай,
       Ты песень наўчыла мяне.

Бяссмертнае слова, ты, роднае слова!
       Ты крыўды, няпраўды змагло;
Хоць гналі цябе, накладалі аковы,
       Дый дарма: жывеш як жыло!

Свабоднае слова, ты, роднае слова!
       Зайграй ты смялей, весялей!
Хоць гадзіны сыкаюць, кружацца совы,
       Жывеш ты на хвалу людзей.

Загнанае слова, ты, роднае слова!
       Грымі ж над радзімай зямлёй:
Што родная мова, хоць бедная мова,
       Мілей найбагатшай чужой!"""
        )
        == """Mahutnaje slova, ty, rodnaje slova!
       Sa mnoj ty na javie i ŭ snie;
Dušu mnie zatresla pahudkaju novaj,
       Ty piesień naŭčyla mianie.

Biassmiertnaje slova, ty, rodnaje slova!
       Ty kryŭdy, niapraŭdy zmahlo;
Choć hnali ciabie, nakladali akovy,
       Dyj darma: žyvieš jak žylo!

Svabodnaje slova, ty, rodnaje slova!
       Zajhraj ty smialiej, viesialiej!
Choć hadziny sykajuć, kružacca sovy,
       Žyvieš ty na chvalu liudziej.

Zahnanaje slova, ty, rodnaje slova!
       Hrymi ž nad radzimaj ziamlioj:
Što rodnaja mova, choć biednaja mova,
       Miliej najbahatšaj čužoj!"""
    )


def test_official_4(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """Несупыннай хваляй плыні
За парою йшла пара,
І прабіла час хлапчыне
Гнаць у поле са двара.
Ён праслухаў навучанку,
Як быць добрым пастухом,
Справіў пугу-павіванку,
Вузлы вывязаў гурком
І пагнаў авечкі ў поле
На папары і на ролі.
Ён цяпер глядзеў больш стала:
Ён – асоба, пастушок,
Нават права меў на сала
І на цёплы кажушок."""
        )
        == """Niesupynnaj chvaliaj plyni
Za paroju jšla para,
I prabila čas chlapčynie
Hnać u polie sa dvara.
Jon prasluchaŭ navučanku,
Jak być dobrym pastuchom,
Spraviŭ puhu-pavivanku,
Vuzly vyviazaŭ hurkom
I pahnaŭ aviečki ŭ polie
Na papary i na roli.
Jon ciapier hliadzieŭ boĺš stala:
Jon – asoba, pastušok,
Navat prava mieŭ na sala
I na cioply kažušok."""
    )


def test_official_5(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """Я бачыў, як змяняе дзень
Вакол мяне гукі на колер,
Як небасхіл пакінуў цень,
Глытаючы слова «ніколі».
Я бачыў праз туман вачэй
Усё часцей ціхае «Хопіць!».
Вядзі мяне. Глядзі ў мяне.
Не ведаю, дзе мы і хто ты.

Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой, неба, небяспечна.

Я бачыў, як вяртае час
Зімовых нас, толькі на поўдзень,
Дзе прамяні не пра мяне
Зрываюць дах, нібыта злодзей.
Я бачыў, як яе далонь
здымае боль сярод пустэчы
Ратуй мяне! Ратуй мяне!
Я ведаю, што будзе лепшым.

Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой, неба, небяспечна.
неба, небяспечна
неба, небяспечна
неба, небяспечна.
Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой.
Баюсь цябе! Баюсь цябе!
І мне цяпер немагчыма збегчы
Ад хуткіх сноў тваіх, але
Мне быць з табой, неба, небяспечна.
неба, небяспечна
неба, небяспечна
неба, небяспечна."""
        )
        == """Ja bačyŭ, jak zmianiaje dzień
Vakol mianie huki na kolier,
Jak niebaschil pakinuŭ cień,
Hlytajučy slova «nikoli».
Ja bačyŭ praz tuman vačej
Usio časciej cichaje «Chopić!».
Viadzi mianie. Hliadzi ŭ mianie.
Nie viedaju, dzie my i chto ty.

Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma zbiehčy
Ad chutkich snoŭ tvaich, alie
Mnie być z taboj, nieba, niebiaspiečna.

Ja bačyŭ, jak viartaje čas
Zimovych nas, toĺki na poŭdzień,
Dzie pramiani nie pra mianie
Zryvajuć dach, nibyta zlodziej.
Ja bačyŭ, jak jaje daloń
zdymaje boĺ siarod pustečy
Ratuj mianie! Ratuj mianie!
Ja viedaju, što budzie liepšym.

Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma zbiehčy
Ad chutkich snoŭ tvaich, alie
Mnie być z taboj, nieba, niebiaspiečna.
nieba, niebiaspiečna
nieba, niebiaspiečna
nieba, niebiaspiečna.
Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma zbiehčy
Ad chutkich snoŭ tvaich, alie
Mnie być z taboj.
Bajuś ciabie! Bajuś ciabie!
I mnie ciapier niemahčyma zbiehčy
Ad chutkich snoŭ tvaich, alie
Mnie być z taboj, nieba, niebiaspiečna.
nieba, niebiaspiečna
nieba, niebiaspiečna
nieba, niebiaspiečna."""
    )


def test_official_6(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """ДОБРА Ў ПОЛІ: ВОЛІ МНОГА
І ПРАСТОРУ-ШЫРЫНІ,
ВАБЯЦЬ ДАЛІ ТАМ МАЛОГА,
ЯК ПРЫНАДНЫЯ АГНІ.
ШТО ЁСЦЬ ТАМ, ЗА ТЫМ, УНЬ, ГАЕМ,
ДЗЕ ЗЛЯГЛІ НЯБЁС ВЯНЦЫ?
НОВЫ КРАЙ І КРАЙ ЗА КРАЕМ
І КРАІ ВА ЎСЕ КАНЦЫ!
І СНУЕЦЦА ДУМКА ТАЯ,
КАБ ПАШЫРЫЦЬ СВОЙ ПРАСТОР;
ДУМКА ЎСЮДЫ ЗАЛЯТАЕ:
ЗА СЯЛО, ЗА ХВАЛІ ГОР
І НА ХМАРКІ КІНЕ ВОКА,
ШТО, ЯК ГУСАНЬКІ, ПЛЫЛІ,
ЗАПЫТАЕ, ЯК ДАЛЁКА
ТОЕ СОНЦА АД ЗЯМЛІ.
ЯК ГЛЫБОК ТОЙ ПРАСТОР НЕМЫ,
І ЦІ МЕРЫЎ ЯГО ХТО?
І АДКАЖА ПА-СВАЕМУ:
ВЁРСТ НАПЭЎНА БУДЗЕ СТО!"""
        )
        == """DOBRA Ŭ POLI: VOLI MNOHA
I PRASTORU-ŠYRYNI,
VABIAĆ DALI TAM MALOHA,
JAK PRYNADNYJA AHNI.
ŠTO JOSĆ TAM, ZA TYM, UŃ, HAJEM,
DZIE ZLIAHLI NIABIOS VIANCY?
NOVY KRAJ I KRAJ ZA KRAJEM
I KRAI VA ŬSIE KANCY!
I SNUJECCA DUMKA TAJA,
KAB PAŠYRYĆ SVOJ PRASTOR;
DUMKA ŬSIUDY ZALIATAJE:
ZA SIALO, ZA CHVALI HOR
I NA CHMARKI KINIE VOKA,
ŠTO, JAK HUSAŃKI, PLYLI,
ZAPYTAJE, JAK DALIOKA
TOJE SONCA AD ZIAMLI.
JAK HLYBOK TOJ PRASTOR NIEMY,
I CI MIERYŬ JAHO CHTO?
I ADKAŽA PA-SVAJEMU:
VIORST NAPEŬNA BUDZIE STO!"""
    )


def test_official_7(scheme_official):
    assert (
        scheme_official.cyr_to_lat(
            """І ЯШЧЭ БЫЛО ЧЫМ МІЛА
ТОЕ ПОЛЕ ХЛАПЧУКУ,
ГЭТА ТЫМ, ШТО ДЗЕД КУРЫЛА
ТАМ ЯГО ТРЫМАЎ РУКУ.
ГЭТЫ ДЗЕД – ПАСТУХ ГУРТОВЫ,
СЛАЎНЫ ДЗЕД, ДЗЯДОК – ДУША,
ГАВАРКІ, МАСТАК НА СЛОВЫ,
І ЛЮБІЎ ЁН МАЛЫША!
НЕ СМЯЯЎСЯ ДЗЕД З СЫМОНКІ,
НЕ ЎСЧУВАЎ ЯГО НІ-НІ,
ЧАСТАВАЎ З СВАЕ СКАРБОНКІ,
БАВІЎ ЦЭЛЫЯ З ІМ ДНІ.
ЗАБЯРУЦЦА Ў ЦЕНЬ ПАД ГРУШУ
І ГАВОРКУ РАСПАЧНУЦЬ.
ТУТ СЫМОНКА СВАЮ ДУШУ
МОГ ПРАД ДЗЕДАМ РАЗГАРНУЦЬ,
ЗАПЫТАЦЬ ПРА СЁЕ-ТОЕ
ДЗЕДКУ ДОБРАГА СВАЙГО,
БО СЫМОН НЕ МЕЎ СПАКОЮ –
ЎСЁ ЦІКАВІЛА ЯГО."""
        )
        == """I JAŠČE BYLO ČYM MILA
TOJE POLIE CHLAPČUKU,
HETA TYM, ŠTO DZIED KURYLA
TAM JAHO TRYMAŬ RUKU.
HETY DZIED – PASTUCH HURTOVY,
SLAŬNY DZIED, DZIADOK – DUŠA,
HAVARKI, MASTAK NA SLOVY,
I LIUBIŬ JON MALYŠA!
NIE SMIAJAŬSIA DZIED Z SYMONKI,
NIE ŬSČUVAŬ JAHO NI-NI,
ČASTAVAŬ Z SVAJE SKARBONKI,
BAVIŬ CELYJA Z IM DNI.
ZABIARUCCA Ŭ CIEŃ PAD HRUŠU
I HAVORKU RASPAČNUĆ.
TUT SYMONKA SVAJU DUŠU
MOH PRAD DZIEDAM RAZHARNUĆ,
ZAPYTAĆ PRA SIOJE-TOJE
DZIEDKU DOBRAHA SVAJHO,
BO SYMON NIE MIEŬ SPAKOJU –
ŬSIO CIKAVILA JAHO."""
    )
